@@ -3,7 +3,6 @@
 # Copyright: (C) Dmitry Shachnev, 2012
 
 from markups import MarkdownMarkup
-import os
 import unittest
 
 tables_source = \
@@ -51,6 +50,9 @@ the family Rosaceae.</dd>
 </dl>
 '''
 
+mathjax_header = \
+'<!--- Type: markdown; Required extensions: mathjax --->\n\n'
+
 mathjax_source = \
 r'''$i_1$ some text \$escaped\$ $i_2$
 
@@ -109,6 +111,10 @@ mathjax_multiline_output = \
 class MarkdownTest(unittest.TestCase):
 	maxDiff = None
 
+	def test_empty_file(self):
+		markup = MarkdownMarkup()
+		self.assertEqual(markup.get_document_body(''), '\n')
+
 	def test_extensions_loading(self):
 		markup = MarkdownMarkup()
 		self.assertFalse(markup._check_extension_exists('nonexistent'))
@@ -124,13 +130,35 @@ class MarkdownTest(unittest.TestCase):
 	def test_remove_extra(self):
 		markup = MarkdownMarkup(extensions=['remove_extra'])
 		html = markup.get_document_body(tables_source)
-		self.assertNotEqual(html, tables_output)
+		self.assertNotIn(html, '<table>')
+
+	def test_remove_extra_document_extension(self):
+		markup = MarkdownMarkup(extensions=[])
+		html = markup.get_document_body(
+			'Required-Extensions: remove_extra\n\n' +
+			tables_source)
+		self.assertNotIn(html, '<table>')
+
+	def test_remove_extra_removes_mathjax(self):
+		markup = MarkdownMarkup()
+		html = markup.get_document_body('$$1$$')
+		self.assertNotIn(html, 'math/tex')
 
 	def test_meta(self):
-		markup = MarkdownMarkup(extensions=['meta'])
-		title = markup.get_document_title('Title: Hello, world!\n\nSome text here.')
+		markup = MarkdownMarkup()
+		text = ('Required-Extensions: meta\n'
+		        'Title: Hello, world!\n\n'
+		        'Some text here.')
+		title = markup.get_document_title(text)
 		self.assertEqual('Hello, world!', title)
 
+	def test_default_math(self):
+		# by default $...$ delimeter should be disabled
+		markup = MarkdownMarkup(extensions=[])
+		self.assertEqual('<p>$1$</p>\n', markup.get_document_body('$1$'))
+		self.assertEqual('<p>\n<script type="math/tex; mode=display">1</script>\n</p>\n',
+			markup.get_document_body('$$1$$'))
+
 	def test_mathjax(self):
 		markup = MarkdownMarkup(extensions=['mathjax'])
 		# Escaping should work
@@ -140,14 +168,16 @@ class MarkdownTest(unittest.TestCase):
 		body = markup.get_document_body(mathjax_source)
 		self.assertEqual(mathjax_output, body)
 
+	def test_mathjax_document_extension(self):
+		markup = MarkdownMarkup()
+		text = mathjax_header + mathjax_source
+		body = markup.get_document_body(text)
+		self.assertEqual(mathjax_header + mathjax_output, body)
+
 	def test_mathjax_multiline(self):
 		markup = MarkdownMarkup(extensions=['mathjax'])
 		body = markup.get_document_body(mathjax_multiline_source)
 		self.assertEqual(mathjax_multiline_output, body)
 
-	def tearDown(self):
-		if os.path.exists('markdown-extensions.txt'):
-			os.remove('markdown-extensions.txt')
-
 if __name__ == '__main__':
 	unittest.main()
